@@ -4,7 +4,7 @@ since many other modules import this one
 """
 __copyright__ = "Copyright 2020, Datera, Inc."
 
-VERSION = "1.2.26"
+VERSION = "1.2.27"
 
 VERSION_HISTORY = """
 Version History:
@@ -50,9 +50,10 @@ Version History:
               local version update during login.
     1.2.25 -- Version increment to workaround PyPI .24 version caching issue
     1.2.26 -- Minor bugfix release.
+    1.2.27 -- v2.3 support
 """
 
-API_VERSIONS = ("v2", "v2.1", "v2.2")
+API_VERSIONS = ("v2", "v2.1", "v2.2", "v2.3")
 
 REST_PORT = 7717
 REST_PORT_HTTPS = 7718
